@@ -47,8 +47,8 @@ sub defaults {
             update      => 0,
             delete      => 0,
 
-            col_menu_addition => 0,
-            parentheses       => 0,
+            extended_cols   => 0,
+            extended_values => 0,
 
             m_derived   => 0,
             join        => 0,
