@@ -48,14 +48,13 @@ sub __session_history {
     # Print history:
     my $tmp_table_print_history = [];
     my $print_history = [];
-    for my $stmt_and_args ( @{$sf->{d}{table_print_history}} ) {
-        my $filled_stmt = $ax->stmt_placeholder_to_value( @$stmt_and_args, 1 );
-        $filled_stmt =~ s/\s*\n\s*/ /g;
-        if ( any { $_->{stmt} eq $filled_stmt } @$subquery_history, @$print_history ) {
+    for my $stmt ( @{$sf->{d}{table_print_history}} ) {
+        $stmt =~ s/\s*\n\s*/ /g;
+        if ( any { $_->{stmt} eq $stmt } @$subquery_history, @$print_history ) {
             next;
         }
-        push @$tmp_table_print_history, $stmt_and_args;
-        push @$print_history, { stmt => $filled_stmt, name => $filled_stmt };
+        push @$tmp_table_print_history, $stmt;
+        push @$print_history, { stmt => $stmt, name => $stmt };
         if ( @$tmp_table_print_history == 7 ) {
             $sf->{d}{table_print_history} = $tmp_table_print_history;
             last;
@@ -88,8 +87,8 @@ sub choose_subquery {
     SUBQUERY: while ( 1 ) {
         my @queries;
         push @queries, map {  '- ' . $_->{name} } @$saved_subqueries;
-        push @queries, map {  '| ' . $_->{name} } @$subquery_history;
-        push @queries, map {  '  ' . $_->{name} } @$print_history;
+        push @queries, map {  '  ' . $_->{name} } @$subquery_history;
+        push @queries, map {  '| ' . $_->{name} } @$print_history;
         my $menu = [ @pre, @queries ];
         my $info = $ax->get_sql_info( $sql );
         # Choose
@@ -114,15 +113,20 @@ sub choose_subquery {
                 ( $saved_subqueries, $subquery_history, $print_history ) = $sf->__get_history();
                 @queries = ();
                 push @queries, map {  '- ' . $_->{name} } @$saved_subqueries;
-                push @queries, map {  '| ' . $_->{name} } @$subquery_history;
-                push @queries, map {  '  ' . $_->{name} } @$print_history;
+                push @queries, map {  '  ' . $_->{name} } @$subquery_history;
+                push @queries, map {  '| ' . $_->{name} } @$print_history;
                 $menu = [ @pre, @queries ];
             }
             next SUBQUERY;
         }
         elsif ( $menu->[$idx] eq $readline ) {
             $prompt = 'Enter SQ: ';
-            $history = [ @{$sql->{cols}} ];
+            if ( @{$sql->{group_by_cols}} || @{$sql->{aggr_cols}} ) {
+                $history = [  @{$sql->{group_by_cols}}, @{$sql->{aggr_cols}} ];
+            }
+            else {
+                $history = [ @{$sql->{cols}} ];
+            }
         }
         else {
             $prompt = 'Edit SQ: ';
